4Suite API Documentation: Ft.Xml.Xslt.Exslt.Math_

4Suite™ API Documentation

# ► Module Ft.Xml.Xslt.Exslt.Math_

EXSLT 2.0 - Math (http://www.exslt.org/math/index.html)

    Copyright 2005 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Functions: ACos, ASin, ATan, ATan2, Abs, Constant, Cos, Exp, Highest, Log, Lowest, Max, Min, Power, Random, Sin, Sqrt, Tan |  |  |  | Globals: CONSTANTS, EXSL_MATH_NS, ExtElements, ExtFunctions, ExtNamespaces

## Functions

ACos(context, num)
  The math:acos function returns the arccosine value of a number.
ASin(context, num)
  The math:asin function returns the arcsine value of a number.
ATan(context, num)
  The math:atan function returns the arctangent value of a number.
ATan2(context, y, x)
  The math:atan2 function returns the angle ( in radians ) from the X axis to a point (y,x).
Abs(context, num)
  The math:abs function returns the absolute value of a number.
Constant(context, name, precision)
  The math:constant function returns the specified constant to a set precision.
Cos(context, num)
  The math:cos function returns cosine of the passed argument.
Exp(context, num)
  The math:exp function returns e (the base of natural logarithms) raised to a power.
Highest(context, nodeset)
  The math:highest function returns the nodes in the node set whose value is the maximum value for the node set. The maximum value for the node set is the same as the value as calculated by math:max. A node has this maximum value if the result of converting its string value to a number as if by the number function is equal to the maximum value, where the equality comparison is defined as a numerical comparison using the = operator.
Log(context, num)
  The math:log function returns the natural logarithm of a number.
Lowest(context, nodeset)
  The math:lowest function returns the nodes in the node set whose value is the minimum value for the node set. The minimum value for the node set is the same as the value as calculated by math:min. A node has this minimum value if the result of converting its string value to a number as if by the number function is equal to the minimum value, where the equality comparison is defined as a numerical comparison using the = operator.
Max(context, nodeset)
  The math:max function returns the maximum value of the nodes passed as the argument.
Min(context, nodeset)
  The math:min function returns the minimum value of the nodes passed as the argument.
Power(context, base, exponent)
  The math:power function returns the value of a base expression taken to a specified power.
Random(context)
  The math:random function returns a random number from 0 to 1.
Sin(context, num)
  The math:sin function returns the sine of the number.
Sqrt(context, num)
  The math:sqrt function returns the square root of a number.
Tan(context, num)
  The math:tan function returns the tangent of the number passed as an argument.

## Globals

CONSTANTS = {'E': 2.7182818284590451, 'LN10': 2.3025850929940459, 'LN2': 0.69314718055994529, 'LOG2E': 1.4426950408889634, 'PI': 3.1415926535897931, 'SQRRT2': 1.4142135623730951, 'SQRT1_2': 0.70710678118654757}
EXSL_MATH_NS = 'http://exslt.org/math'
ExtElements = {}
ExtFunctions = {('http://exslt.org/math', 'abs'): <function Abs>, ('http://exslt.org/math', 'acos'): <function ACos>, ('http://exslt.org/math', 'asin'): <function ASin>, ('http://exslt.org/math', 'atan'): <function ATan>, ('http://exslt.org/math', 'atan2'): <function ATan2>, ('http://exslt.org/math', 'constant'): <function Constant>, ('http://exslt.org/math', 'cos'): <function Cos>, ('http://exslt.org/math', 'exp'): <function Exp>, ('http://exslt.org/math', 'highest'): <function Highest>, ('http://exslt.org/math', 'log'): <function Log>, ...}
ExtNamespaces = {'http://exslt.org/math': 'math'}